@@ -1,34 +1,8 @@
-#!/usr/bin/env python
-# $Id: anti_flood_ftpd.py 1262 2014-04-11 22:13:10Z g.rodola $
+#!/usr/bin/env python3
 
-#  pyftpdlib is released under the MIT license, reproduced below:
-#  ======================================================================
-#  Copyright (C) 2007-2014 Giampaolo Rodola' <g.rodola@gmail.com>
-#
-#                         All Rights Reserved
-#
-# Permission is hereby granted, free of charge, to any person
-# obtaining a copy of this software and associated documentation
-# files (the "Software"), to deal in the Software without
-# restriction, including without limitation the rights to use,
-# copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the
-# Software is furnished to do so, subject to the following
-# conditions:
-#
-# The above copyright notice and this permission notice shall be
-# included in all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
-# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
-# OTHER DEALINGS IN THE SOFTWARE.
-#
-#  ======================================================================
+# Copyright (C) 2007 Giampaolo Rodola' <g.rodola@gmail.com>.
+# Use of this source code is governed by MIT license that can be
+# found in the LICENSE file.
 
 """
 A FTP server banning clients in case of commands flood.
@@ -37,22 +11,23 @@ If client sends more than 300 requests per-second it will be
 disconnected and won't be able to re-connect for 1 hour.
 """
 
+from pyftpdlib.authorizers import DummyAuthorizer
 from pyftpdlib.handlers import FTPHandler
 from pyftpdlib.servers import FTPServer
-from pyftpdlib.authorizers import DummyAuthorizer
 
 
 class AntiFloodHandler(FTPHandler):
 
     cmds_per_second = 300  # max number of cmds per second
-    ban_for = 60 * 60      # 1 hour
+    ban_for = 60 * 60  # 1 hour
     banned_ips = []
 
     def __init__(self, *args, **kwargs):
         FTPHandler.__init__(self, *args, **kwargs)
         self.processed_cmds = 0
-        self.pcmds_callback = \
-            self.ioloop.call_every(1, self.check_processed_cmds)
+        self.pcmds_callback = self.ioloop.call_every(
+            1, self.check_processed_cmds
+        )
 
     def on_connect(self):
         # called when client connects.
@@ -98,12 +73,13 @@ class AntiFloodHandler(FTPHandler):
 
 def main():
     authorizer = DummyAuthorizer()
-    authorizer.add_user('user', '12345', '.', perm='elradfmw')
+    authorizer.add_user('user', '12345', '.', perm='elradfmwMT')
     authorizer.add_anonymous('.')
     handler = AntiFloodHandler
     handler.authorizer = authorizer
     server = FTPServer(('', 2121), handler)
     server.serve_forever(timeout=1)
 
+
 if __name__ == '__main__':
     main()
