@@ -1,46 +1,20 @@
-#!/usr/bin/env python
-# $Id: unix_daemon.py 1262 2014-04-11 22:13:10Z g.rodola $
+#!/usr/bin/env python3
 
-#  pyftpdlib is released under the MIT license, reproduced below:
-#  ======================================================================
-#  Copyright (C) 2007-2014 Giampaolo Rodola' <g.rodola@gmail.com>
-#
-#                         All Rights Reserved
-#
-# Permission is hereby granted, free of charge, to any person
-# obtaining a copy of this software and associated documentation
-# files (the "Software"), to deal in the Software without
-# restriction, including without limitation the rights to use,
-# copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the
-# Software is furnished to do so, subject to the following
-# conditions:
-#
-# The above copyright notice and this permission notice shall be
-# included in all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
-# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
-# OTHER DEALINGS IN THE SOFTWARE.
-#
-#  ======================================================================
+# Copyright (C) 2007 Giampaolo Rodola' <g.rodola@gmail.com>.
+# Use of this source code is governed by MIT license that can be
+# found in the LICENSE file.
 
 """A basic unix daemon using the python-daemon library:
-http://pypi.python.org/pypi/python-daemon
+http://pypi.python.org/pypi/python-daemon.
 
 Example usages:
 
- $ python unix_daemon.py start
- $ python unix_daemon.py stop
- $ python unix_daemon.py status
- $ python unix_daemon.py  # foreground (no daemon)
- $ python unix_daemon.py --logfile /var/log/ftpd.log start
- $ python unix_daemon.py --pidfile /var/run/ftpd.pid start
+ $ python3 unix_daemon.py start
+ $ python3 unix_daemon.py stop
+ $ python3 unix_daemon.py status
+ $ python3 unix_daemon.py  # foreground (no daemon)
+ $ python3 unix_daemon.py --logfile /var/log/ftpd.log start
+ $ python3 unix_daemon.py --pidfile /var/run/ftpd.pid start
 
 This is just a proof of concept which demonstrates how to daemonize
 the FTP server.
@@ -56,20 +30,18 @@ Authors:
  - Giampaolo Rodola' - g.rodola <at> gmail.com
 """
 
-from __future__ import with_statement
-
-import os
+import argparse
+import atexit
 import errno
+import os
+import signal
 import sys
 import time
-import optparse
-import signal
-import atexit
 
-from pyftpdlib.handlers import FTPHandler
-from pyftpdlib.servers import FTPServer
 from pyftpdlib.authorizers import UnixAuthorizer
 from pyftpdlib.filesystems import UnixFilesystem
+from pyftpdlib.handlers import FTPHandler
+from pyftpdlib.servers import FTPServer
 
 
 # overridable options
@@ -81,17 +53,11 @@ WORKDIR = os.getcwd()
 UMASK = 0
 
 
-def print_(s):
-    sys.stdout.write(s + '\n')
-    sys.stdout.flush()
-
-
 def pid_exists(pid):
     """Return True if a process with the given PID is currently running."""
     try:
         os.kill(pid, 0)
-    except OSError:
-        err = sys.exc_info()[1]
+    except OSError as err:
         return err.errno == errno.EPERM
     else:
         return True
@@ -102,8 +68,7 @@ def get_pid():
     try:
         with open(PID_FILE) as f:
             return int(f.read().strip())
-    except IOError:
-        err = sys.exc_info()[1]
+    except IOError as err:
         if err.errno != errno.ENOENT:
             raise
 
@@ -122,10 +87,9 @@ def stop():
         sys.stdout.flush()
         try:
             os.kill(pid, sig)
-        except OSError:
-            e = sys.exc_info()[1]
-            if e.errno == errno.ESRCH:
-                print_("\nstopped (pid %s)" % pid)
+        except OSError as err:
+            if err.errno == errno.ESRCH:
+                print("\nstopped (pid %s)" % pid)
                 return
             else:
                 raise
@@ -141,9 +105,9 @@ def status():
     """Print daemon status and exit."""
     pid = get_pid()
     if not pid or not pid_exists(pid):
-        print_("daemon not running")
+        print("daemon not running")
     else:
-        print_("daemon running with pid %s" % pid)
+        print("daemon running with pid %s" % pid)
     sys.exit(0)
 
 
@@ -158,6 +122,7 @@ def get_server():
 
 def daemonize():
     """A wrapper around python-daemonize context manager."""
+
     def _daemonize():
         pid = os.fork()
         if pid > 0:
@@ -178,7 +143,7 @@ def daemonize():
         # redirect standard file descriptors
         sys.stdout.flush()
         sys.stderr.flush()
-        si = open(LOG_FILE, 'r')
+        si = open(LOG_FILE)
         so = open(LOG_FILE, 'a+')
         se = open(LOG_FILE, 'a+', 0)
         os.dup2(si.fileno(), sys.stdin.fileno())
@@ -187,9 +152,8 @@ def daemonize():
 
         # write pidfile
         pid = str(os.getpid())
-        f = open(PID_FILE, 'w')
-        f.write("%s\n" % pid)
-        f.close()
+        with open(PID_FILE, 'w') as f:
+            f.write("%s\n" % pid)
         atexit.register(lambda: os.remove(PID_FILE))
 
     pid = get_pid()
@@ -204,39 +168,51 @@ def daemonize():
 
 def main():
     global PID_FILE, LOG_FILE
-    USAGE = "python [-p PIDFILE] [-l LOGFILE]\n\n" \
-            "Commands:\n  - start\n  - stop\n  - status"
-    parser = optparse.OptionParser(usage=USAGE)
-    parser.add_option('-l', '--logfile', dest='logfile',
-                      help='the log file location')
-    parser.add_option('-p', '--pidfile', dest='pidfile', default=PID_FILE,
-                      help='file to store/retreive daemon pid')
-    options, args = parser.parse_args()
+    USAGE = "python3 [-p PIDFILE] [-l LOGFILE]\n\n"
+    USAGE += "Commands:\n  - start\n  - stop\n  - status"
+
+    parser = argparse.ArgumentParser(usage=USAGE)
+    parser.add_argument(
+        '-l', '--logfile', dest='logfile', help='the log file location'
+    )
+    parser.add_argument(
+        '-p',
+        '--pidfile',
+        dest='pidfile',
+        default=PID_FILE,
+        help='file to store/retrieve daemon pid',
+    )
+    parser.add_argument(
+        'command',
+        nargs='?',
+        help='command to execute: start, stop, restart, status',
+    )
+
+    options = parser.parse_args()
 
     if options.pidfile:
         PID_FILE = options.pidfile
     if options.logfile:
         LOG_FILE = options.logfile
 
-    if not args:
+    if not options.command:
         server = get_server()
         server.serve_forever()
     else:
-        if len(args) != 1:
-            sys.exit('too many commands')
-        elif args[0] == 'start':
+        if options.command == 'start':
             daemonize()
-        elif args[0] == 'stop':
+        elif options.command == 'stop':
             stop()
-        elif args[0] == 'restart':
+        elif options.command == 'restart':
             try:
                 stop()
             finally:
                 daemonize()
-        elif args[0] == 'status':
+        elif options.command == 'status':
             status()
         else:
             sys.exit('invalid command')
 
+
 if __name__ == '__main__':
     sys.exit(main())
